pycocoa.deprecated.DeepestScreen

Package pycocoa :: Module deprecated :: Class DeepestScreen |
[frames] | no frames]

# Class DeepestScreen

              object --+
                       |
    internals._Objectype --+
                           |
            baseTypes._Type0 --+
                               |
                  screens.Screen --+
                                   |
                   _DeprecatedScreen --+
                                       |
                                      DeepestScreen

DEPRECATED on 2025.03.16, use `Screens.Deepest`.

Instance Methods
Inherited from `_DeprecatedScreen`: `__init__` Inherited from `screens.Screen`: `__eq__`, `cascade` Inherited from `baseTypes._Type0`: `__repr__`, `__str__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `screens.Screen`: `__new__`

Properties
Inherited from `screens.Screen`: `bottom`, `bottomleft`, `bottomright`, `center`, `colorSpace`, `deviceDescription`, `deviceDict`, `displayID`, `frame`, `isBuiltIn`, `isExternal`, `isMain`, `isPrinter`, `isScreen`, `left`, `name`, `named`, `origin`, `pixels`, `ratio`, `resolutions`, `right`, `size`, `top`, `topleft`, `topright`, `visibleFrame` Inherited from `baseTypes._Type0`: `NS`, `NSDelegate` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`